@@ -48,11 +48,11 @@ fn option_keys() {
 	let t: std::collections::BTreeMap<Option<String>, u8> = crate::from_bytes(b"
 		any: 3
 		2: 1
-		none: 2
+		: 2
 	").unwrap();
 	assert_eq!(t, std::array::IntoIter::new([
 		(None, 2),
-		(Some("any".into()), 3),
 		(Some("2".into()), 1),
+		(Some("any".into()), 3),
 	]).collect())
 }
